==> cronapp-framework-java-2.7.3.jar: cronapp/framework/authentication/external/ExternalAuthenticationConfig.java <==
package cronapp.framework.authentication.external;

import cronapi.AppConfig;
import org.springframework.security.authentication.ProviderNotFoundException;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;

import java.util.HashSet;
import java.util.Set;

public class ExternalAuthenticationConfig {

  private static String type;

  private static final String INTERNAL = "internal";

  private static final String FACEBOOK = "facebook";

  private static final String LINKEDIN = "linkedin";

  private static final String CRONAPP = "cronapp";

  private static final String GOOGLE = "google";

  private static final String GITHUB = "github";

  private static final String TOKEN = "Token";

  private static final String NORMAL = "Normal";

  private static final String ACTIVE_DIRECTORY = "activeDirectory";

  private static final String LDAP = "ldap";

  private static final String SAML = "Saml";

  private static Set<String> SOCIAL = new HashSet<>();

  static {
    type = AppConfig.type();
    SOCIAL.add(FACEBOOK);
    SOCIAL.add(LINKEDIN);
    SOCIAL.add(CRONAPP);
    SOCIAL.add(GOOGLE);
    SOCIAL.add(GITHUB);
  }

  public static String getExternalAuthType() {
    return type;
  }

  public static boolean isExternalAuth() {
    return !INTERNAL.equalsIgnoreCase(type)
        && !TOKEN.equalsIgnoreCase(type)
        && !NORMAL.equalsIgnoreCase(type)
        && !SAML.equalsIgnoreCase(type);
  }

  public static boolean isSocial(String provider) {
    return SOCIAL.contains(provider.toLowerCase());
  }

  public static Authentication authenticateExternally(Authentication authentication) throws AuthenticationException {
    return authenticator(type).authenticate(authentication);
  }

  private static ExternalAuthenticator authenticator(String type) {
    if (ACTIVE_DIRECTORY.equalsIgnoreCase(type)) {
      return new ActiveDirectoryAuthenticator();
    } else if (LDAP.equalsIgnoreCase(type)) {
      return new LdapAuthenticator();
    }
    throw new ProviderNotFoundException(String.format("No AuthenticationProvider found for %s", type));
  }
}

==> cronapp-framework-java-2.8.17.jar: cronapp/framework/authentication/external/ExternalAuthenticationConfig.java <==
package cronapp.framework.authentication.external;

import cronapi.AppConfig;
import org.springframework.security.authentication.ProviderNotFoundException;
import org.springframework.security.core.Authentication;
import org.springframework.security.core.AuthenticationException;

import java.util.HashSet;
import java.util.Set;

public class ExternalAuthenticationConfig {

  private static String type;

  private static final String INTERNAL = "internal";

  private static final String FACEBOOK = "facebook";

  private static final String LINKEDIN = "linkedin";

  private static final String CRONAPP = "cronapp";

  private static final String GOOGLE = "google";

  private static final String GITHUB = "github";

  private static final String TOKEN = "Token";

  private static final String NORMAL = "Normal";

  private static final String ACTIVE_DIRECTORY = "activeDirectory";

  private static final String LDAP = "ldap";

  private static final String SAML = "Saml";

  private static final String SSO = "SSO";

  private static Set<String> SOCIAL = new HashSet<>();

  static {
    type = AppConfig.type();
    SOCIAL.add(FACEBOOK);
    SOCIAL.add(LINKEDIN);
    SOCIAL.add(CRONAPP);
    SOCIAL.add(GOOGLE);
    SOCIAL.add(GITHUB);
  }

  public static String getExternalAuthType() {
    return type;
  }

  public static boolean isExternalAuth() {
    return !INTERNAL.equalsIgnoreCase(type)
        && !TOKEN.equalsIgnoreCase(type)
        && !NORMAL.equalsIgnoreCase(type)
        && !SAML.equalsIgnoreCase(type)
        && !SSO.equalsIgnoreCase(type);
  }

  public static boolean isSocial(String provider) {
    return SOCIAL.contains(provider.toLowerCase());
  }

  public static Authentication authenticateExternally(Authentication authentication) throws AuthenticationException {
    return authenticator(type).authenticate(authentication);
  }

  private static ExternalAuthenticator authenticator(String type) {
    if (ACTIVE_DIRECTORY.equalsIgnoreCase(type)) {
      return new ActiveDirectoryAuthenticator();
    } else if (LDAP.equalsIgnoreCase(type)) {
      return new LdapAuthenticator();
    }
    throw new ProviderNotFoundException(String.format("No AuthenticationProvider found for %s", type));
  }
}
